@@ -2,6 +2,14 @@ import HistoryMatch from "./components/HistoryMatch";
 import Map from "./components/Map";
 import Morris from "./components/Morris";
 import LayeredMap from "./components/LayeredMap";
+import LeafletMap from "./components/LeafletMap";
 import PriorPosteriorDistribution from "./components/PriorPosteriorDistribution";
 
-export { HistoryMatch, Morris, Map, LayeredMap, PriorPosteriorDistribution };
+export {
+    HistoryMatch,
+    Morris,
+    Map,
+    LayeredMap,
+    PriorPosteriorDistribution,
+    LeafletMap,
+};
